@@ -1,6 +1,6 @@
 from nose import SkipTest
 try:
-    from django.conf import settings
+    import django
 except ImportError:
     raise SkipTest()
 
@@ -14,5 +14,8 @@ except ImportError:
 # module-global imports in our test submodules still run
 # first.
 
+from django.apps import apps
 from django.conf import settings
-settings.configure(INSTALLED_APPS=['django_assets'])
+
+settings.configure(INSTALLED_APPS=['django_assets', 'django.contrib.staticfiles'])
+apps.populate(settings.INSTALLED_APPS)
